<!--- 
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the PT Comments directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2009-2016.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files 
in this directory, you agree to the terms and conditions of the applicable 
end user license agreement.
--->
<!---
/* *************************************************************** */
Author: 	
	PaperThin, Inc.
Name:
	comments_listing_rh.cfm
Summary:
	Renders the comments listings. Loads them via AJAX in to a div
Arguments:
	request.params.callback -  if a callback script name value is passed in to this RH it will render a 
							   the 'post comment' button with callback key/value in the URL
							   and add an script to refresh the comments DIV
History:
	2009-12-23 - MFC - Created
	2010-01-06 - GAC - Modified - Added a callback option to refresh just the comments div.
	2012-09-12 - MFC - Updated the JQuery calls to load the comments.
					   Updated the CSS to include a separate file.
	2013-03-22 - DMB - Updated to not write to request.params structure.  Added new request.comments structure.
	2013-05-01 - MFC - Removed the any reference to saving the "FormID" field for the comment content.
						Updated the form lightbox URL parameters.
	2016-02-25 - DRM - Resource detection exit
--->

<!--- if this module loads resources, do it here.. --->
<cfscript>
	application.ptComments.scripts.loadJQuery();
	application.ptComments.scripts.loadJQueryUI();
	application.ptComments.scripts.loadADFLightbox();
</cfscript>

<!--- ... then exit if all we're doing is detecting required resources --->
<cfif Request.RenderState.RenderMode EQ "getResources">
  <cfexit>
</cfif>


<cfscript>
	// Render each time the page is refreshed since a new comment may have be added
	request.element.isStatic = 0;
	request.comments = structNew();
	formID = application.ptcomments.getCommentsFormID();
	
	// get the items
	items = attributes.elementInfo.elementData.propertyValues;	

	// Validate if the comments structure exists to post comments
	if ( StructKeyExists(request, "comments") 
		AND StructKeyExists(request.comments, "contentDataPageID") ){
		// Set the content Form ID from the Content Page ID
		request.comments.contentDataPageID = request.params.comments.contentDataPageID;
	}
	else {
		request.comments.contentDataPageID = 0;
	}
	
	// Set the flag to render the action links for the comments
	renderActionLinks = false;
	if ( request.renderState.renderMode NEQ "read" )
		renderActionLinks = true;
</cfscript>

<cfif (request.comments.contentDataPageID GT 0)>
	<cfoutput>
		<script type="text/javascript">
			jQuery(document).ready(function(){
				// Load the comments DIV when the page is loaded
				loadComments();
			});
			
			// Pull in the comments data and output them in the comments DIV
			function loadComments(){
				
				// Display the loading image
				//loadingHTML = 'Loading Comments ... <img src="/ADF/apps/pt_comments/images/ajax-loader-arrows.gif">';
				//jQuery("div##comment_listing").html(loadingHTML);
				
				jQuery.get("#application.ADF.ajaxProxy#",
				{ 
					bean: "commentRender",
					method: "getListingHTML",
					contentDataPageID: "#request.comments.contentDataPageID#",
					displayMailto: "Y"
				},
				function (data){
					jQuery("div##comment_listing").html(data); 
				});
			}

			function addCommentsReturn(formdata){
				
				//console.log(formdata);
				// convert to JSON

				var formJSON = JSON.stringify(formdata);
				jQuery.get("#application.ADF.ajaxProxy#",
					{
						bean: "forms_1_1",
						method: "verifyCFFormProtect",
						formStruct: formJSON,
						returnFormat: "HTML",
						elementName: 'comments',
						primaryKey: 'uid'
					},function(results){
			  			closeLBReloadParent();
					}
			    );
			   }
		</script>
		<!--- Load the styles --->
		<link rel="stylesheet" type="text/css" href="/ADF/apps/pt_comments/style/ptComments.css">
		<br />
		<h4>Comments</h4>
		
		<!--- Render the comments --->
		<div class="comment_listing" id="comment_listing">
			Loading Comments ... <img src="/ADF/apps/pt_comments/images/ajax-loader-arrows.gif">
		</div>
		
		<!--- Check if the user is logged in --->
		<cfif request.user.id GT 0>
			<div id="addComment">
				<script type="text/javascript">
					// Load JQuery UI effects for the "ds-icons" and "ui_button" classes
					jQuery(document).ready(function(){
						// Hover states on the static widgets
						jQuery("a.addCommentButton div.ui-button").hover(
							function() { 
								jQuery(this).css("cursor", "hand");
								jQuery(this).addClass('ui-state-hover');
							},
							function() { 
								jQuery(this).css("cursor", "pointer");
								jQuery(this).removeClass('ui-state-hover');
							}
						);
					});
				</script>
					<a rel="#application.ADF.ajaxProxy#?bean=commentForms&method=renderAddForm&contentDataPageID=#request.comments.contentDataPageID#&commentUserID=#request.user.id#&callback=loadComments&title=Post a Comment" class="ADFLightbox addCommentButton" title='Post A Comment'>
					<div class='ui-button ui-state-default ui-corner-all' title='Download Poll Data Report'>
						<div class='ui-icon ui-icon-comment'></div>
						<div class='addCommentText'>Post A Comment</div>
					</div>
				</a>			
			</div>
		<cfelse>
			<div id="addNew" style="padding: 20px 20px 20px 0px;">
				<p>
					<a href="login.cfm">Please Login to post a comment</a>
				</p>
			</div>
		</cfif>
	</cfoutput>
<cfelse>
	<cfoutput>
		<!-- PT Comments [#request.formattedTimeStamp#]: No Content Form ID and Content Data Page ID are defined. -->
	</cfoutput>
</cfif>

<cfoutput>


</cfoutput>